summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocumentChild.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoDocumentChild.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoDocumentChild.h')
-rw-r--r--lib/kofficecore/KoDocumentChild.h41
1 files changed, 21 insertions, 20 deletions
diff --git a/lib/kofficecore/KoDocumentChild.h b/lib/kofficecore/KoDocumentChild.h
index 349961ed..228122dc 100644
--- a/lib/kofficecore/KoDocumentChild.h
+++ b/lib/kofficecore/KoDocumentChild.h
@@ -21,8 +21,8 @@
#include <KoChild.h>
#include <koffice_export.h>
-class QDomDocument;
-class QDomElement;
+class TQDomDocument;
+class TQDomElement;
class KURL;
class KoStore;
class KoDocument;
@@ -43,22 +43,23 @@ class KoXmlWriter;
class KOFFICECORE_EXPORT KoDocumentChild : public KoChild
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoDocumentChild( KoDocument* parent, KoDocument* doc, const QRect& geometry );
+ KoDocumentChild( KoDocument* tqparent, KoDocument* doc, const TQRect& tqgeometry );
/**
* When using this constructor you must call @ref #setDocument before
* you can call any other function of this class.
*/
- KoDocumentChild( KoDocument* parent );
+ KoDocumentChild( KoDocument* tqparent );
virtual ~KoDocumentChild();
/**
* Call this function only directly after calling the constructor
* that takes only a parent as argument.
*/
- virtual void setDocument( KoDocument *doc, const QRect &geometry );
+ virtual void setDocument( KoDocument *doc, const TQRect &tqgeometry );
/**
* @return document contained in this child
@@ -68,13 +69,13 @@ public:
KoDocument *document() const;
/**
* @return parent document of this child
*
* @see KoDocument
*/
- virtual KoDocument *parentDocument() const; // TODO: remove virtual, makes no sense
+ virtual KoDocument *tqparentDocument() const; // TODO: remove virtual, makes no sense
- virtual KoDocument* hitTest( const QPoint& p, const QWMatrix& _matrix = QWMatrix() );
+ virtual KoDocument* hitTest( const TQPoint& p, const TQWMatrix& _matrix = TQWMatrix() );
/**
* @note Can be empty (which is why it doesn't return a const KURL &)
@@ -93,20 +94,20 @@ public:
*
* @return the element containing the "object" tag.
*/
- virtual QDomElement save( QDomDocument& doc, bool uppercase=false );
+ virtual TQDomElement save( TQDomDocument& doc, bool uppercase=false );
/**
* Save an embedded object to OASIS.
* This method sets the attributes for the draw:object element in the parent XML document.
* It also prepares the embedded object for being saved into the store at
* the end of saving (see saveOasisToStore).
* Note that @p name is only used for "internal" documents (not extern).
*/
- void saveOasisAttributes( KoXmlWriter &xmlWriter, const QString& name );
+ void saveOasisAttributes( KoXmlWriter &xmlWriter, const TQString& name );
/**
* Save an embedded object to an OASIS store.
* This is called automatically by the parent KoDocument's saveOasis
*/
virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );
@@ -120,9 +121,9 @@ public:
* @ref KoDocument::loadChildren, respectively from your implementation
* of these methods.
*/
- virtual bool load( const QDomElement& element, bool uppercase=false );
+ virtual bool load( const TQDomElement& element, bool uppercase=false );
- void loadOasis( const QDomElement &frameElement, const QDomElement& objectElement );
+ void loadOasis( const TQDomElement &frameElement, const TQDomElement& objectElement );
/**
* Actually loads the document from the disk/net or from the store,
@@ -134,7 +135,7 @@ public:
* Actually loads the document from the disk/net or from the store
* depending on the document's url
*/
- virtual bool loadOasisDocument( KoStore* store, const QDomDocument& manifestDoc );
+ virtual bool loadOasisDocument( KoStore* store, const TQDomDocument& manifestDoc );
virtual bool isStoredExtern() const;
@@ -153,24 +154,24 @@ protected: // Should be private, but KWord needs access to the variables
* set after parsing the OBJECT tag in @ref #load and is reset after
* calling @ref #loadDocument.
*/
- QString m_tmpURL;
+ TQString m_tmpURL;
/**
* This variable is
* set after parsing the OBJECT tag in @ref #load and is reset after
* calling @ref #loadDocument.
*/
- QRect m_tmpGeometry;
+ TQRect m_tmpGeometry;
/**
* This variable is
* set after parsing the OBJECT tag in @ref #load and is reset after
* calling @ref #loadDocument.
*/
- QString m_tmpMimeType;
+ TQString m_tmpMimeType;
private:
- bool createUnavailDocument( KoStore* store, bool doOpenURL, const QString& mimeType );
+ bool createUnavailDocument( KoStore* store, bool doOpenURL, const TQString& mimeType );
bool loadDocumentInternal( KoStore* _store, const KoDocumentEntry& e, bool doOpenURL, bool oasis );
private:
@@ -43,22 +43,23 @@ class KoXmlWriter;
/**
* Call this function only directly after calling the constructor
- * that takes only a parent as argument.
+ * that takes only a tqparent as argument.
*/
@@ -68,13 +69,13 @@ public:
KoDocument *document() const;
/**
- * @return parent document of this child
+ * @return tqparent document of this child
*
* @see KoDocument
@@ -93,20 +94,20 @@ public:
/**
* Save an embedded object to OASIS.
- * This method sets the attributes for the draw:object element in the parent XML document.
+ * This method sets the attributes for the draw:object element in the tqparent XML document.
* It also prepares the embedded object for being saved into the store at
* the end of saving (see saveOasisToStore).
@@ -93,20 +94,20 @@ public:
/**
* Save an embedded object to an OASIS store.
- * This is called automatically by the parent KoDocument's saveOasis
+ * This is called automatically by the tqparent KoDocument's saveOasis
*/
virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );